<?php
/**
 * @package     Joomla.Site
 * @subpackage  com_contact
 *
 * @copyright   Copyright (C) 2005 - 2020 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

JHtml::_('behavior.core');

?>


<style>
.contact-content {
    display: grid;
    grid-template-columns: repeat(auto-fill, minmax(20rem, 1fr));
    grid-gap: 1rem;
	text-align: center;
}

.contact-item {
    display: flex;
    flex-direction: column;
    align-content: space-between;
}

.contact-image img {
    object-fit: cover;
    height: 250px;
    width: 250px;
    border-radius: 50%;
    box-shadow: 0px 0px 10px 2px #ddd;
}

.contact-position {
    font-style: italic;
    background-color: #E7E9EA;
    margin: 6px 60px;
    border-radius: 8px;
}

.contact-name a{
	color: #33434C;
	font-size: 1.2rem;
	font-weight: bold;
}

.contact-description{
	color: #33434C;
}

.contact-phone svg {
    width: 25px;
}

.contact-phone {
    display: flex;
    justify-content: center;
    font-weight: bold;
    color: #3C6650;
}

</style>


<form action="<?php echo htmlspecialchars(JUri::getInstance()->toString()); ?>" method="post" name="adminForm" id="adminForm">
	<?php if ($this->params->get('filter_field') || $this->params->get('show_pagination_limit')) : ?>
		<fieldset class="filters btn-toolbar">
			<?php if ($this->params->get('filter_field')) : ?>
				<div class="btn-group">
					<label class="filter-search-lbl element-invisible" for="filter-search">
						<span class="label label-warning">
							<?php echo JText::_('JUNPUBLISHED'); ?>
						</span>
							<?php echo JText::_('COM_CONTACT_FILTER_LABEL') . '&#160;'; ?>
					</label>
					<input
						type="text"
						name="filter-search"
						id="filter-search"
						value="<?php echo $this->escape($this->state->get('list.filter')); ?>"
						class="inputbox"
						onchange="document.adminForm.submit();"
						title="<?php echo JText::_('COM_CONTACT_FILTER_SEARCH_DESC'); ?>"
						placeholder="<?php echo JText::_('COM_CONTACT_FILTER_SEARCH_DESC'); ?>"
					/>
				</div>
			<?php endif; ?>
			<?php if ($this->params->get('show_pagination_limit')) : ?>
				<div class="btn-group pull-right">
					<label for="limit" class="element-invisible">
						<?php echo JText::_('JGLOBAL_DISPLAY_NUM'); ?>
					</label>
					<?php echo $this->pagination->getLimitBox(); ?>
				</div>
			<?php endif; ?>
		</fieldset>
	<?php endif; ?>
	<?php if (empty($this->items)) : ?>
		<p>
			<?php echo JText::_('COM_CONTACT_NO_CONTACTS'); ?>
		</p>
	<?php else : ?>
		<div class="contact-content">
			<?php foreach ($this->items as $i => $item) : ?>
				<?php if (in_array($item->access, $this->user->getAuthorisedViewLevels())) : ?>
					<?php if ($this->items[$i]->published == 0) : ?>
						<div class="system-unpublished contact-item">
					<?php else : ?>
						<div class="row-fluid contact-item" >
					<?php endif; ?>					
						
					<div class="contact-image">

						<?php if ($this->items[$i]->image) : ?>							
							<a href="<?php echo JRoute::_(ContactHelperRoute::getContactRoute($item->slug, $item->catid)); ?>">
								<?php echo JHtml::_(
									'image',
									$this->items[$i]->image,
									JText::_('COM_CONTACT_IMAGE_DETAILS'),
									array('class' => 'contact-thumbnail img-thumbnail')
								); ?>
							</a>								
						<?php else: ?>									
							<a href="<?php echo JRoute::_(ContactHelperRoute::getContactRoute($item->slug, $item->catid)); ?>">
								<?php echo JHtml::_(
									'image',
									'images/institutional/pattern/images/avatar.jpg',
									JText::_('COM_CONTACT_IMAGE_DETAILS'),
									array('class' => 'contact-thumbnail img-thumbnail')
								); ?>
							</a>
						<?php endif; ?>

					</div>
										
					<div class="contact-description">
						<div class="contact-name">
							<a href="<?php echo JRoute::_(ContactHelperRoute::getContactRoute($item->slug, $item->catid)); ?>">
								<?php echo $item->name; ?>
							</a>
						</div>
						
						<?php if ($this->items[$i]->published == 0) : ?>
							<span class="label label-warning">
								<?php echo JText::_('JUNPUBLISHED'); ?>
							</span>
						<?php endif; ?>
						<?php echo $item->event->afterDisplayTitle; ?>
						<?php echo $item->event->beforeDisplayContent; ?>
						
						<?php if ($this->params->get('show_position_headings')) : ?>
							<div class="contact-position">
								<?php echo $item->con_position; ?>
							</div>							
						<?php endif; ?>

						<?php if ($this->params->get('show_email_headings')) : ?>
							<?php echo $item->email_to; ?><br />
						<?php endif; ?>
						<?php $location = array(); ?>
						<?php if ($this->params->get('show_suburb_headings') && !empty($item->suburb)) : ?>
							<?php $location[] = $item->suburb; ?>
						<?php endif; ?>
						<?php if ($this->params->get('show_state_headings') && !empty($item->state)) : ?>
							<?php $location[] = $item->state; ?>
						<?php endif; ?>
						<?php if ($this->params->get('show_country_headings') && !empty($item->country)) : ?>
							<?php $location[] = $item->country; ?>
						<?php endif; ?>
						<?php echo implode(', ', $location); ?>

						<div class="contact-phone">
							<?php if ($this->params->get('show_telephone_headings') && !empty($item->telephone)) : ?>

								<svg aria-hidden="true" focusable="false" data-prefix="fas" data-icon="phone-alt"  xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512">
									<path fill="currentColor" 
									d="M497.39 361.8l-112-48a24 24 0 0 0-28 6.9l-49.6 60.6A370.66 370.66 0 0 1 
										130.6 204.11l60.6-49.6a23.94 23.94 0 0 0 6.9-28l-48-112A24.16 24.16 0 0 
										0 122.6.61l-104 24A24 24 0 0 0 0 48c0 256.5 207.9 464 464 464a24 24 0 0 
										0 23.4-18.6l24-104a24.29 24.29 0 0 0-14.01-27.6z">
									</path>
								</svg>
								<?php echo $item->telephone; ?>
							<?php endif; ?>
							<?php if ($this->params->get('show_mobile_headings') && !empty ($item->mobile)) : ?>
								<?php echo JText::sprintf('COM_CONTACT_MOBILE_NUMBER', $item->mobile); ?><br />
							<?php endif; ?>
							<?php if ($this->params->get('show_fax_headings') && !empty($item->fax)) : ?>
								<?php echo JText::sprintf('COM_CONTACT_FAX_NUMBER', $item->fax); ?><br />
							<?php endif; ?>
						</div>
					</div>
					
					<?php echo $item->event->afterDisplayContent; ?>
				</div>
				<?php endif; ?>
			<?php endforeach; ?>
		</div>
	<?php endif; ?>
	<?php if ($this->params->get('show_pagination', 2)) : ?>
		<div class="pagination">
			<?php if ($this->params->def('show_pagination_results', 1)) : ?>
				<p class="counter">
					<?php echo $this->pagination->getPagesCounter(); ?>
				</p>
			<?php endif; ?>
			<?php echo $this->pagination->getPagesLinks(); ?>
		</div>
	<?php endif; ?>
	<div>
		<input type="hidden" name="filter_order" value="<?php echo $this->escape($this->state->get('list.ordering')); ?>" />
		<input type="hidden" name="filter_order_Dir" value="<?php echo $this->escape($this->state->get('list.direction')); ?>" />
	</div>
</form>
